@@ -2,6 +2,7 @@ import html
 from typing import List, Optional, Iterable, cast
 
 import pandas as pd
+import plac
 import streamlit as st
 from annotated_text import div, annotation
 from collections_extended import RangeMap
@@ -11,7 +12,7 @@ from streamlit.uploaded_file_manager import UploadedFile
 # fmt: off
 from .util import get_token, get_projects, get_project_by_label, get_project, get_annotators, get_annotator_by_label, \
     has_converter, has_formatter, annotate_text, annotate_format_text, \
-    annotate_binary, annotate_format_binary, LOGO
+    annotate_binary, annotate_format_binary, LOGO, clean_html, clean_annotation
 
 # fmt: on
 FOOTER = """<span style="font-size: 0.75em">&hearts; Built with [Streamlit](https://streamlit.io/) and largerly inspired by the great [`spacy-streamlit`](https://github.com/explosion/spacy-streamlit)</span>"""
@@ -21,7 +22,7 @@ def visualize(  # noqa: C901
         default_text: str = "",
         projects: List[str] = None,
         annotators: List[str] = None,
-        annotator_types: Iterable[str] = (),
+        annotator_types: Iterable[str] = None,
         favorite_only: bool = False,
         show_project: bool = True,
         show_annotator: bool = True,
@@ -29,19 +30,21 @@ def visualize(  # noqa: C901
         sidebar_description: Optional[str] = None,
         show_logo: bool = True,
         color: Optional[str] = "#09A3D5",
-        key: Optional[str] = None,
-        get_default_text: str = None,
+        key: Optional[str] = None
 ) -> None:
     """Embed the full visualizer with selected components."""
-    st.set_page_config(
-        layout="wide",
-        initial_sidebar_state="expanded",
-        menu_items={
-            'Get Help': 'https://www.extremelycoolapp.com/help',
-            'Report a bug': "https://www.extremelycoolapp.com/bug",
-            'About': "# This is a header. This is an *extremely* cool app!"
-        }
-    )
+    try:
+        st.set_page_config(
+            layout="wide",
+            initial_sidebar_state="expanded",
+            menu_items={
+                'Get Help': 'https://www.extremelycoolapp.com/help',
+                'Report a bug': "https://www.extremelycoolapp.com/bug",
+                'About': "# This is a header. This is an *extremely* cool app!"
+            }
+        )
+    except BaseException as e:  # noqa: F841
+        pass
     if st.config.get_option("theme.primaryColor") != color:
         st.config.set_option("theme.primaryColor", color)
 
@@ -79,13 +82,16 @@ def visualize(  # noqa: C901
                 project = get_project_by_label(url, st.session_state.project, st.session_state.token)
                 all_annotators = get_annotators(url,
                                                 project,
-                                                tuple(annotator_types), favorite_only,
+                                                tuple(annotator_types) if annotator_types is not None else None,
+                                                favorite_only,
                                                 st.session_state.token) if project is not None else []
                 selected_annotators = sorted(
                     [p['label'] for p in all_annotators if annotators is None or p['name'] in annotators])
                 st.sidebar.selectbox('Select annotator', selected_annotators, key="annotator")
                 if st.session_state.get('annotator', None) is not None:
-                    annotator = get_annotator_by_label(url, project, tuple(annotator_types), favorite_only,
+                    annotator = get_annotator_by_label(url, project,
+                                                       tuple(annotator_types) if annotator_types is not None else None,
+                                                       favorite_only,
                                                        st.session_state.annotator, st.session_state.token)
 
             if show_project or show_annotator:
@@ -187,8 +193,8 @@ def visualize_annotated_doc(
         for cat in categories:
             score = cat.get('score', 1.0)
             color = labels.get(cat['labelName'], {}).get('color', "#333")
-            categorized.append((cat['label'], "{:.0%}".format(score), color))
-            categorized.append((" ", "", ""))
+            categorized.append(clean_annotation(cat['label'], "{:.0%}".format(score), color))
+            categorized.append(" ")
 
         html = annotated_text(*categorized)
         st.write(html, unsafe_allow_html=True)
@@ -203,18 +209,17 @@ def visualize_annotated_doc(
         annotated = []
         for r in annotation_map.ranges():
             if r.start > start:
-                annotated.append(text[start:r.start])
+                annotated.append(clean_html(text[start:r.start]))
             a = r.value
             color = labels.get(a['labelName'], {}).get('color', "#333")
-            annotated.append((text[r.start:r.stop], a['labelName'], color))
+            annotated.append(clean_annotation(text[r.start:r.stop], clean_html(a['label']), color))
             start = r.stop
         if start < len(text):
-            annotated.append(text[start:])
+            annotated.append(clean_html(text[start:]))
     else:
         annotated = [text]
 
     html = annotated_text(*annotated)
-    html = html.replace("\n\n", "\n")
     st.write(html, unsafe_allow_html=True)
     #
     # if show_table:
@@ -284,5 +289,10 @@ def annotated_text(*args):
 
     return str(out)
 
-# if __name__ == "__main__":
-#     plac.call(main)
+
+def main():
+    pass
+
+
+if __name__ == "__main__":
+    plac.call(main)
